==> img0ch-2.1.9.zip: img0ch/_template/default/i_read.cs <==
<html>
<title><?cs var:Subject ?></title>
<base href="<?cs var:html_escape(RCGIURI) ?>/<?cs if:BBS ?><?cs var:html_escape(BBS) ?>/<?cs /if ?><?cs if:KEY ?><?cs var:html_escape(KEY) ?>/<?cs /if ?><?cs if:BaseQueryString ?>!<?cs var:html_escape(QueryString) ?>/<?cs /if ?><?cs var:html_escape(RawOption) ?>">
</head>
<body
<?cs if:TextColor ?> text=#<?cs var:html_escape(TextColor) ?><?cs /if ?>
<?cs if:BackGroundColor ?> bgcolor=#<?cs var:html_escape(BackGroundColor) ?><?cs /if ?>
<?cs if:LinkColor ?> link=#<?cs var:html_escape(LinkColor) ?><?cs /if ?>
<?cs if:ALinkColor ?> alink=#<?cs var:html_escape(ALinkColor) ?><?cs /if ?>
<?cs if:VLinkColor ?> vlink=#<?cs var:html_escape(VLinkColor) ?><?cs /if ?>
>
<?cs if:Fontsize ?><font size=<?cs var:html_escape(Fontsize) ?>><?cs /if ?>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>
<a name=u></a>
<?cs if:Write ?>
<?cs if:WriteForm ?>
<hr><form method=post action=<?cs var:html_escape(CGIURI) ?>/bbs.cgi utn>
<input type=hidden name=key value=<?cs var:html_escape(KEY) ?>>
<input name=FROM size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(NameByCookie) ?><?cs /if ?>><br>
<input name=mail size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(MailByCookie) ?><?cs /if ?>><br>
<textarea name=MESSAGE></textarea><br><input type=submit value= accesskey=4>
<input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
<input type=hidden name=time value=<?cs var:html_escape(TimeStamp) ?>>
<input type=hidden name=get value=1>
<input type=hidden name=submit>
</form><hr><a href=i></a>
<?cs elif:SettingForm ?>
<a name=u></a>
<a href="#d" accesskey=8></a>
ݒ<br>
<hr>
<form action=SET>
<input name=mode type=hidden value=SET>\ݒ脟<br>
<input type=checkbox name=1a value=1 checked>ftHgAAS<br>
<input type=checkbox name=1b value=on>ȗ<br>
X<input name=THREAD size=4 istyle=1 value=30>\<br>
X<input name=RES size=4 istyle=4 value=10>\<br>
X<input name=LINE size=4 istyle=4 value=10>sŏȗ<br>
ftHg<br>
:<input name=FROM size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(NameByCookie) ?><?cs /if ?>><br>
:<input name=mail size=14 istyle=4<?cs if:NameByCookie ?> value=<?cs var:html_escape(MailByCookie) ?><?cs /if ?>><br>
<input type=submit value=>
<hr>
HTMLXL(zF)<br>
:#<input name=txt size=14 istyle=4 value=<?cs if:TextColor ?><?cs var:html_escape(TextColor) ?><?cs else ?>000000<?cs /if ?>><br>
wi:#<input name=bgc size=14 istyle=4 value=<?cs if:BackGroundColor ?><?cs var:html_escape(BackGroundColor) ?><?cs else ?>efefef<?cs /if ?>><br>
N:#<input name=link size=14 istyle=4 value=<?cs if:LinkColor ?><?cs var:html_escape(LinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
ǃN:#<input name=vlink size=14 istyle=4 value=<?cs if:VLinkColor ?><?cs var:html_escape(VLinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
NbN:#<input name=alink size=14 istyle=4 value=<?cs if:ALinkColor ?><?cs var:html_escape(ALinkColor) ?><?cs else ?>FFFFFF<?cs /if ?>><br>
TCY:<input name=size size=14 istyle=4 value=<?cs if:Fontsize ?><?cs var:html_escape(Fontsize) ?><?cs else ?>3<?cs /if ?>><br>
<input type=submit value=>
</form><hr>
<a name=d></a>
<a href="SET#u" accesskey=2></a>
<?cs elif:SettingSaved ?>
ݒ芮<br><a href="./!<?cs var:html_escape(QueryString) ?>/i">ubN}[NĂ</a>B
</html>
<?cs /if ?>
<?cs else ?>
<a href=#b accesskey=8></a>
<br><?cs var:Subject ?>
<?cs if:Copy ?>
<hr><?cs each:item = Thread ?>
<form action=i><textarea>
<?cs var:html_escape(item.index) ?>:<?cs var:item.name ?><?cs var:html_escape(item.date) ?>
<?cs if:item.mail ?>
 [<?cs var:html_escape(item.mail) ?>]
 <?cs /if ?>
<?cs var:CR ?><?cs var:item.text ?>
</textarea><br>
<?cs /each ?><br>
<?cs else ?>
<?cs each:item = Thread ?>
<hr><?cs var:html_escape(item.resno) ?>:<b><?cs var:item.name ?></b><?cs var:html_escape(item.date) ?>
<?cs if:item.mail ?>
 [<?cs var:html_escape(item.mail) ?>]
 <?cs /if ?>
<?cs if:AAS ?>
<a href='http://example.ddo.jp/aas/a.i/
<?cs var:html_escape(AASBase) ?>/
<?cs var:html_escape(BBS) ?>/
<?cs var:html_escape(KEY) ?>/
<?cs var:html_escape(item.index) ?>'>AAS</a>
<?cs /if ?><br>
<?cs var:item.text ?>
<?cs /each ?><hr>
<?cs /if ?>
<a name=b></a>
<a href=#u accesskey=2></a>
<a href=<?cs var:html_escape(PrevStart) ?>-<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=7>O</a>
<a href=<?cs var:html_escape(NextStart) ?>-<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=9></a>
<a href=1-<?cs if:AAS ?>a<?cs /if ?> accesskey=1>1-</a>
<a href=n<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=3>V</a>
<a href=w accesskey=4></a>
<a href=<?cs var:html_escape(RawOption) ?><?cs if:!Copy ?>c<?cs /if ?> accesskey=5></a>
<a href=../<?cs if:QueryString ?>../!<?cs var:html_escape(QueryString) ?>/<?cs /if ?> accesskey=6></a>
<a href=<?cs var:html_escape(RawOption) ?><?cs if:!AAS ?>a<?cs /if ?>>AA</a>
<a href=SET accesskey=#></a>
<?cs if:BBS_ACCEPT_MAILPOST ?>
<br><a href=<?cs var:html_escape(CGIURI) ?>/m.cgi/<?cs var:html_escape(BBS) ?>/>X</a>
(<a href=mailto:<?cs var:MailPostAddress ?>?
subject=<?cs var:html_escape(BBS_NONAME_NAME) ?>&lt;&gt;sage&
body=<?cs var:html_escape(BBS) ?>&lt;&gt;<?cs var:html_escape(KEY) ?>&lt;&gt;ɖ{Ă>
gтҰقœe
</a>)
<?cs /if ?>
<br>
<form action=i>
<textarea>
<?cs var:Subject ?><?cs var:html_escape(CR) ?>
<?cs var:html_escape(ReadCGIURI) ?>/l50
</textarea>
</form>
<?cs /if ?>
</body>
</html>

==> img0ch-2.1.10.zip: img0ch/_template/default/i_read.cs <==
<html>
<title><?cs var:Subject ?></title>
<base href="<?cs var:html_escape(RCGIURI) ?>/<?cs if:BBS ?><?cs var:html_escape(BBS) ?>/<?cs /if ?><?cs if:KEY ?><?cs var:html_escape(KEY) ?>/<?cs /if ?><?cs if:BaseQueryString ?>!<?cs var:html_escape(QueryString) ?>/<?cs /if ?><?cs var:html_escape(RawOption) ?>">
</head>
<body
<?cs if:TextColor ?> text=#<?cs var:html_escape(TextColor) ?><?cs /if ?>
<?cs if:BackGroundColor ?> bgcolor=#<?cs var:html_escape(BackGroundColor) ?><?cs /if ?>
<?cs if:LinkColor ?> link=#<?cs var:html_escape(LinkColor) ?><?cs /if ?>
<?cs if:ALinkColor ?> alink=#<?cs var:html_escape(ALinkColor) ?><?cs /if ?>
<?cs if:VLinkColor ?> vlink=#<?cs var:html_escape(VLinkColor) ?><?cs /if ?>
>
<?cs if:Fontsize ?><font size=<?cs var:html_escape(Fontsize) ?>><?cs /if ?>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>
<a name=u></a>
<?cs if:Write ?>
<?cs if:WriteForm ?>
<form method=post action=<?cs var:html_escape(CGIURI) ?>/bbs.cgi utn>
<input type=hidden name=key value=<?cs var:html_escape(KEY) ?>>
<input name=FROM size=14<?cs if:NameByCookie ?> value="<?cs var:html_escape(NameByCookie) ?>"<?cs /if ?>><br>
<input name=mail size=14<?cs if:NameByCookie ?> value="<?cs var:html_escape(MailByCookie) ?>"<?cs /if ?>><br>
<textarea name=MESSAGE></textarea><br><input type=submit value= accesskey=4>
<input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
<input type=hidden name=time value=<?cs var:html_escape(TimeStamp) ?>>
<input type=hidden name=get value=1>
<input type=hidden name=submit>
</form><hr><a href=i></a>
<?cs elif:SettingForm ?>
<a name=u></a>
<a href="#d" accesskey=8></a>
ݒ<br>
<hr>
<form action=SET>
<input name=mode type=hidden value=SET>\ݒ脟<br>
<input type=checkbox name=1a value=1 checked>ftHgAAS<br>
<input type=checkbox name=1b value=on>ȗ<br>
X<input name=THREAD size=4 istyle=1 value=30>\<br>
X<input name=RES size=4 istyle=4 value=10>\<br>
X<input name=LINE size=4 istyle=4 value=10>sŏȗ<br>
ftHg<br>
:<input name=FROM size=14<?cs if:NameByCookie ?> value="<?cs var:html_escape(NameByCookie) ?>"<?cs /if ?>><br>
:<input name=mail size=14 istyle=4<?cs if:NameByCookie ?> value="<?cs var:html_escape(MailByCookie) ?>"<?cs /if ?>><br>
<input type=submit value=>
<hr>
HTMLXL(zF)<br>
:#<input name=txt size=14 istyle=4 value=<?cs if:TextColor ?><?cs var:html_escape(TextColor) ?><?cs else ?>000000<?cs /if ?>><br>
wi:#<input name=bgc size=14 istyle=4 value=<?cs if:BackGroundColor ?><?cs var:html_escape(BackGroundColor) ?><?cs else ?>efefef<?cs /if ?>><br>
N:#<input name=link size=14 istyle=4 value=<?cs if:LinkColor ?><?cs var:html_escape(LinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
ǃN:#<input name=vlink size=14 istyle=4 value=<?cs if:VLinkColor ?><?cs var:html_escape(VLinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
NbN:#<input name=alink size=14 istyle=4 value=<?cs if:ALinkColor ?><?cs var:html_escape(ALinkColor) ?><?cs else ?>FFFFFF<?cs /if ?>><br>
TCY:<input name=size size=14 istyle=4 value=<?cs if:Fontsize ?><?cs var:html_escape(Fontsize) ?><?cs else ?>3<?cs /if ?>><br>
<input type=submit value=>
</form><hr>
<a name=d></a>
<a href="SET#u" accesskey=2></a>
<?cs elif:SettingSaved ?>
ݒ芮<br><a href="./!<?cs var:html_escape(QueryString) ?>/i">ubN}[NĂ</a>B
</html>
<?cs /if ?>
<?cs else ?>
<a href=#b accesskey=8></a>
<br><?cs var:Subject ?>
<?cs if:Copy ?>
<hr><?cs each:item = Thread ?>
<form action=i><textarea>
<?cs var:html_escape(item.index) ?>:<?cs var:item.name ?><?cs var:html_escape(item.date) ?>
<?cs if:item.mail ?>
 [<?cs var:html_escape(item.mail) ?>]
 <?cs /if ?>
<?cs var:CR ?><?cs var:item.text ?>
</textarea><br>
<?cs /each ?><br>
<?cs else ?>
<?cs each:item = Thread ?>
<hr><?cs var:html_escape(item.resno) ?>:<b><?cs var:item.name ?></b><?cs var:html_escape(item.date) ?>
<?cs if:item.mail ?>
 [<?cs var:html_escape(item.mail) ?>]
 <?cs /if ?>
<?cs if:AAS ?>
<a href='http://example.ddo.jp/aas/a.i/
<?cs var:html_escape(AASBase) ?>/
<?cs var:html_escape(BBS) ?>/
<?cs var:html_escape(KEY) ?>/
<?cs var:html_escape(item.index) ?>'>AAS</a>
<?cs /if ?><br>
<?cs var:item.text ?>
<?cs /each ?><hr>
<?cs /if ?>
<a name=b></a>
<a href=#u accesskey=2></a>
<a href=<?cs var:html_escape(PrevStart) ?>-<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=7>O</a>
<a href=<?cs var:html_escape(NextStart) ?>-<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=9></a>
<a href=1-<?cs if:AAS ?>a<?cs /if ?> accesskey=1>1-</a>
<a href=n<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=3>V</a>
<a href=w accesskey=4></a>
<a href=<?cs var:html_escape(RawOptionNoC) ?><?cs if:!Copy ?>c<?cs /if ?> accesskey=5></a>
<a href=../<?cs if:QueryString ?>../!<?cs var:html_escape(QueryString) ?>/<?cs /if ?> accesskey=6></a>
<a href=<?cs var:html_escape(RawOptionNoA) ?><?cs if:!AAS ?>a<?cs /if ?>>AA</a>
<a href=SET accesskey=#></a>
<?cs if:BBS_ACCEPT_MAILPOST ?>
<br><a href=<?cs var:html_escape(CGIURI) ?>/m.cgi/<?cs var:html_escape(BBS) ?>/>X</a>
(<a href=mailto:<?cs var:MailPostAddress ?>?
subject=<?cs var:html_escape(BBS_NONAME_NAME) ?>&lt;&gt;sage&
body=<?cs var:html_escape(BBS) ?>&lt;&gt;<?cs var:html_escape(KEY) ?>&lt;&gt;ɖ{Ă>
gтҰقœe
</a>)
<?cs /if ?>
<br>
<form action=i>
<textarea>
<?cs var:Subject ?><?cs var:html_escape(CR) ?>
<?cs var:html_escape(ReadCGIURI) ?>/l50
</textarea>
</form>
<?cs /if ?>
</body>
</html>
